VectorField

Trait VectorField 

pub trait VectorField {
    // Required method
    fn velocity(&self, x: &ArrayView1<'_, f64>, t: f64) -> Array1<f64>;
}
A vector field representing a continuous drift in a (latent) space.

Required Methods

fn velocity(&self, x: &ArrayView1<'_, f64>, t: f64) -> Array1<f64>

Evaluate the velocity at point x and time t.

Implementors