pub trait VectorField { // Required method fn velocity(&self, x: &ArrayView1<'_, f64>, t: f64) -> Array1<f64>; }
A vector field representing a continuous drift in a (latent) space.
Evaluate the velocity at point x and time t.
x
t